@@ -15,7 +15,7 @@
   * License along with this library; if not, write to the Free
   * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
   *
-  * $Id: apache.mli,v 1.11 2004/08/03 16:54:31 rwmj Exp $
+  * $Id: apache.mli,v 1.12 2004/10/23 11:49:57 rwmj Exp $
   *)
 
 type result_type = OK | DECLINED | DONE
@@ -298,18 +298,23 @@ module Request :
 	= "mod_caml_request_internal_redirect_handler"
     (** Internally redirects immediately to [uri] using handler specified
       by [r]. *)
-    external print_char : t -> char -> unit = "mod_caml_request_print_char"
-    (** Send a character back to the client. *)
-    external print_string : t -> string -> unit
+    external print_char : t -> char -> int = "mod_caml_request_print_char"
+    (** Send a character back to the client.  Returns the character
+      * written, cast to int, or [-1] on failure.
+      *)
+    external print_string : t -> string -> int
       = "mod_caml_request_print_string"
-    (** Send a string back to the client. *)
-    val print_int : t -> int -> unit
+    (** Send a string back to the client.  Returns the number of bytes
+      * actually written, which is smaller than the number of bytes in
+      * the string if there was a failure.
+      *)
+    val print_int : t -> int -> int
     (** Send a decimal number back to the client. *)
-    val print_float : t -> float -> unit
+    val print_float : t -> float -> int
     (** Send a floating-point number back to the client. *)
-    val print_newline : t -> unit
+    val print_newline : t -> int
     (** Send a CR LF back to the client. *)
-    val print_endline : t -> string -> unit
+    val print_endline : t -> string -> int
     (** Send a string followed by CR LF back to the client. *)
     external register_cleanup : t -> (unit -> unit) -> unit
         = "mod_caml_request_register_cleanup"
@@ -321,17 +326,17 @@ module Request :
 type handler_t = Request.t -> result_type
 (** The type of handler functions. *)
 
-val print_char : Request.t -> char -> unit
+val print_char : Request.t -> char -> int
 (** Send a character back to the client. *)
-val print_string : Request.t -> string -> unit
+val print_string : Request.t -> string -> int
 (** Send a string back to the client. *)
-val print_int : Request.t -> int -> unit
+val print_int : Request.t -> int -> int
 (** Send a decimal number back to the client. *)
-val print_float : Request.t -> float -> unit
+val print_float : Request.t -> float -> int
 (** Send a floating-point number back to the client. *)
-val print_newline : Request.t -> unit
+val print_newline : Request.t -> int
 (** Send a CR LF back to the client. *)
-val print_endline : Request.t -> string -> unit
+val print_endline : Request.t -> string -> int
 (** Send a string followed by CR LF back to the client. *)
 
 module type DbiDriverT = sig
