@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: apache_c.c,v 1.11 2004/07/16 08:36:42 rwmj Exp $
+ * $Id: apache_c.c,v 1.12 2004/10/23 11:49:57 rwmj Exp $
  */
 
 #include "config.h"
@@ -680,10 +680,7 @@ mod_caml_request_print_char (value rv, value cv)
   int c = Int_val (cv);
   int i = ap_rputc (c, r);
 
-  if (i == -1)
-    failwith ("mod_caml_print_char: failed"); /* XXX */
-
-  CAMLreturn (Val_unit);
+  CAMLreturn (Val_int (i));
 }
 
 CAMLprim value
@@ -695,10 +692,7 @@ mod_caml_request_print_string (value rv, value strv)
   int n = string_length (strv);
   int i = ap_rwrite (str, n, r);
 
-  if (i < n)
-    failwith ("mod_caml_print_string: failed"); /* XXX */
-
-  CAMLreturn (Val_unit);
+  CAMLreturn (Val_int (i));
 }
 
 static int
