@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: maillist.ml,v 1.5 2004/08/03 16:54:31 rwmj Exp $
+ * $Id: maillist.ml,v 1.6 2004/09/11 16:31:44 rwmj Exp $
  *
  * To get this working you need to locate registry.cmo and create a caml-bin
  * directory containing maillist.cmo. Then set up Apache like this:
@@ -52,7 +52,7 @@ let (//) = Filename.concat
 
 let path =
   try Sys.getenv "MAILLIST_TEMPLATESDIR"
-  with Not_found -> "/usr/lib/mod_caml/templates"
+  with Not_found -> "/usr/share/mod_caml/templates"
 
 let template = Template.template (path // "maillist.html")
 let body = Template.template (path // "maillist-body.txt")
