@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: registry.ml,v 1.5 2004/09/27 11:56:41 rwmj Exp $
+ * $Id: registry.ml,v 1.6 2004/10/23 11:49:57 rwmj Exp $
  *
  * CGI scripts are loaded dynamically into memory, and stay there unless
  * you restart the server or the file changes on disk.
@@ -73,8 +73,10 @@ let handler r =
   let filename = Request.filename r in
   let finfo =
     match Request.finfo r with
-	None -> failwith (filename ^ ": no request->finfo: probably means " ^
-			  "the file does not exist.")
+      | None ->
+	  prerr_endline (filename ^ ": no request->finfo: probably means " ^
+			 "the file does not exist.");
+	  raise (HttpError cHTTP_NOT_FOUND)
       | Some finfo -> finfo
   in
   let mtime = finfo.st_mtime in
