@@ -17,7 +17,7 @@
   * License along with this library; if not, write to the Free
   * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
   *
-  * $Id: template.mli,v 1.2 2004/04/16 15:07:45 rwmj Exp $
+  * $Id: template.mli,v 1.3 2004/10/21 21:32:30 rwmj Exp $
   *)
 
 type table_row_t = (string * var_t) list
@@ -38,7 +38,7 @@ and var_t = VarString of string
   [::call(fname,arg1,...)::]) *)
 
 class template :
-  string ->
+  ?filename:string -> string ->
 object
   method set : string -> string -> unit
     (** Set a variable in the template. *)
@@ -65,8 +65,8 @@ end
 val template : string -> template
   (** Compile the template from a named file. *)
 
-val template_from_string : string -> template
+val template_from_string : ?filename:string -> string -> template
   (** Compile the template from a literal string. *)
 
-val template_from_channel : in_channel -> template
+val template_from_channel : ?filename:string -> in_channel -> template
   (** Compile the template from a channel. *)
